# ChangeLog


## v1.3.1

* Reload boot/tools when they are changed

## v1.3.0

* Load cherrypy tools from app_dir/tools
* Load modules on app start from app_dir/boot

## v1.2.8

* Set lang to 'en' when hostname has no dot

## v1.2.7

* Make session("key") available on templates

## v1.2.6

* Add controller.render()

## v1.2.5

* Provide environment variables for templates on "env"
* Add support for CORS using CORS_DOMAIN

## v1.2.4

* support variables injection on template render()

## v1.2.3

* reload web server when modules in the lib dir are updated

## v1.2.2

* load modules from application lib/ dir

## v1.2.1

* fix get_domain() with localhost (thanks to Oana Apostol for reporting)

## v1.2.0

* added lang support

## v1.1.0

* added support for dbsupport.py within app dir

## v1.0.1

* Update to python3

## v1.0.0
